@@ -1,4 +1,4 @@
-from .function import LambdaFunction, QueueFunction
+from .function import LambdaFunction, QueueFunction, ScheduleFunction
 from .api_function import APIFunction
 from jinja2 import Environment, FileSystemLoader
 import os
@@ -70,12 +70,30 @@ class Deployer(object):
         functions = []
         classes = QueueFunction.__subclasses__()
         for lambda_class in classes:
-            if lambda_class.__name__ not in ["APIFunction", "QueueFunction"]:
+            if lambda_class.__name__ not in [
+                "APIFunction",
+                "QueueFunction",
+                "ScheduleFunction",
+            ]:
                 functions.append(
                     {"name": lambda_class.__name__, "queue": lambda_class.queue}
                 )
         return functions
 
+    def _get_schedule_functions(self):
+        functions = []
+        classes = ScheduleFunction.__subclasses__()
+        for lambda_class in classes:
+            if lambda_class.__name__ not in [
+                "APIFunction",
+                "QueueFunction",
+                "ScheduleFunction",
+            ]:
+                functions.append(
+                    {"name": lambda_class.__name__, "schedule": lambda_class.schedule}
+                )
+        return functions
+
     def _install_reqs(self):
         reqs = os.path.abspath(f"{self.dir}/requirements.txt")
         subprocess.run(["pip", "install", "-r", reqs], check=True)
@@ -117,6 +135,7 @@ class Deployer(object):
         queues = self._get_queues()
 
         queue_functions = self._get_queue_functions()
+        schedule_functions = self._get_schedule_functions()
 
         rendered = template.render(
             description="Test",
@@ -129,6 +148,7 @@ class Deployer(object):
             domain=self.domain,
             queues=queues,
             queue_functions=queue_functions,
+            schedule_functions=schedule_functions,
             pool_id=self.pool_id,
             certificate_id=self.certificate_id,
             account_id=self.account_id,
